package model

import androidx.compose.ui.graphics.Color
import org.jetbrains.compose.resources.DrawableResource
import org.jetbrains.compose.resources.ExperimentalResourceApi
import kotlin.time.Duration

enum class TagType {
    COURSE,         // Breads, Apps, Desserts, Entrees, etc
    CUISINE,        // Country or Ethnicity of Origin
    FLAVOUR,        // Spicy, Sweet, Sour, Umami, Delicious
    TECHNIQUE,        // Fried, Baked, Boiled, Poached, etc
    EXAMPLES,       // Example Recipes that might only appear in debug mode?
}

/**
 * Sourced from abdulbasit
 */

data class Recipe @OptIn(ExperimentalResourceApi::class) constructor(
    //val id: Int,
    val title: String,
    val description: String,
    val prepTime: Duration,
    val cookTime: Duration,
    val servings: String = "Enough",
    val ingredients: List<String>,
    val instructions: List<String>,
    val tags: Map<String, TagType>,
    val image: DrawableResource,
    val linkedRecipes : List<Recipe> = listOf(),
    var bgColor: Color = Color.White,
)

