package recipeslist

/**
 * Created by abdulbasit on 18/06/2023.
 */

import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.aspectRatio
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.Card
import androidx.compose.material3.MaterialTheme
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import model.Recipe

@OptIn(ExperimentalSharedTransitionApi::class)
@Composable
fun RecipeListItem(
    recipe: Recipe,
    onClick: (recipe: Recipe) -> Unit,
    largeList: Boolean
) {
    Box(modifier = Modifier) {
        Box(modifier = Modifier.padding(top = 8.dp, start = 16.dp, end = 16.dp, bottom = 16.dp)
            .fillMaxWidth().aspectRatio(if (largeList) 6.5f else 1.5f)
            .shadow(
                elevation = 16.dp,
                shape = RoundedCornerShape(35.dp),
                clip = true,
                ambientColor = Color(0xffCE5A01),
                spotColor = Color(0xffCE5A01)
            )
            .background(recipe.bgColor, RoundedCornerShape(35.dp)).fillMaxHeight().clickable {
                onClick(recipe)
            }) {
            Card(
                backgroundColor = recipe.bgColor,
                shape = RoundedCornerShape(35.dp),
                modifier = Modifier.clip(RoundedCornerShape(35.dp)),
            )
            {
                Box(
                    modifier = Modifier.fillMaxWidth().aspectRatio(if (largeList) 4.5f else 1.5f)
                ) {
                    Row(
                        modifier = Modifier.fillMaxHeight().padding(16.dp).fillMaxWidth(0.55f),
                        verticalAlignment = Alignment.Bottom
                    ) {
                        Column(modifier = Modifier.align(if (largeList) Alignment.Top else Alignment.Bottom)) {
                            Text(
                                text = recipe.title,
                                style = if(largeList)MaterialTheme.typography.bodyLarge else MaterialTheme.typography.headlineMedium,
                                overflow = TextOverflow.Clip,
                                color = MaterialTheme.colorScheme.onSecondaryContainer
                            )

                            if (largeList.not()) {
                                Text(
                                    recipe.description,
                                    style = MaterialTheme.typography.displayMedium,
                                    maxLines = 3,
                                    overflow = TextOverflow.Ellipsis,
                                    color = MaterialTheme.colorScheme.onPrimaryContainer,
                                )
                            }
                        }
                        Spacer(modifier = Modifier.weight(1f))
                    }
                }
                RecipeListItemImageWrapper(modifier = Modifier.align(Alignment.BottomEnd)
                    .fillMaxWidth(0.45f).aspectRatio(1f), child = {
                    RecipeImage(
                        imageBitmap = recipe.image, modifier = Modifier.clip(
                            CircleShape
                        )
                    )
                })
            }
        }
    }
}
